@@ -132,13 +132,23 @@ class NeutronData(object):
 
         ports_by_role_and_host = {}
         for port in self.ports:
+            # Ignore ports in networks we ignore, i.e the OVN Bridge MAC net
+            if port.network_id not in self.networks_by_id:
+                continue
+
             tags = self._tags_to_dict(port.tags)
+
             # In case of missing required tags, raise an error.
             # neutron is useless as a inventory source in this case.
             if not mandatory_tags.issubset(tags):
                 raise exception.MissingMandatoryNeutronResourceTag()
 
             hostname = port.dns_name
+            # Strip the final fqdn dot of the hostname
+            # See: https://bugs.launchpad.net/tripleo/+bug/1928869
+            if hostname.endswith('.'):
+                hostname = hostname[:-1]
+
             network_id = port.network_id
             network = self.networks_by_id[network_id]
             fixed_ips = port.fixed_ips[0]
@@ -148,6 +158,11 @@ class NeutronData(object):
             # "TripleO" cidr is the number of bits in the network mask
             cidr = subnet['cidr'].split('/')[1]
             dns_domain = network['dns_domain']
+            # Strip the final fqdn dot of the dnsname
+            # See: https://bugs.launchpad.net/tripleo/+bug/1928869
+            if dns_domain.endswith('.'):
+                dns_domain = dns_domain[:-1]
+
             dns_nameservers = subnet['dns_nameservers']
             mtu = network['mtu']
             net_name = network['name']
@@ -192,6 +207,10 @@ class NeutronData(object):
         mandatory_tags = {'tripleo_network_name'}
         networks_by_id = {}
         for net in self.networks:
+            # Don't include the OVN Bridge MAC address net
+            if net.name == constants.OVN_MAC_ADDR_NET_NAME:
+                continue
+
             tags = self._tags_to_dict(net.tags)
             # In case of missing required tags, raise an error.
             # neutron is useless as a inventory source in this case.
@@ -465,6 +484,26 @@ class TripleoInventory(object):
             if not ports:
                 return None
 
+            # Filter tripleo_service_vip and tripleo_vip_net ports
+            ports = [p for p in ports
+                     if not any("tripleo_service_vip" in tag for tag in p.tags)
+                     and not any("tripleo_vip_net" in tag for tag in p.tags)]
+
+            # NOTE(hjensas): ctlplane ports created by THT Heat Server
+            # resources, or nova less without --network-ports/--network-config
+            # enabled, does not have the 'tripleo_stack_name' tag. We
+            # shouldn't use neutron as a source if no ctlplane ports are
+            # tagged with the 'tripleo_stack_name'.
+            # See bug: https://bugs.launchpad.net/tripleo/+bug/1928926
+            found_ctlplane_port = False
+            ctlplane_net = conn.network.find_network(self.host_network)
+            for p in ports:
+                if p.network_id == ctlplane_net.id:
+                    found_ctlplane_port = True
+                    break
+            if not found_ctlplane_port:
+                return None
+
             networks = [conn.network.find_network(p.network_id)
                         for p in ports]
             subnets = []
